@@ -73,6 +73,7 @@ $LANG_LINKS = array(
     124 => 'Go',
     125 => 'Categories',
     126 => 'You are here:',
+    'autotag_desc_link' => '[link: id alternate title] - Displays a link to a Link from the Links Plugin using the Link Title as the title. An alternate title may be specified but is not required.',
     'root' => 'Root' // title used for top level category
 );
 
@@ -170,7 +171,7 @@ $LANG_LINKS_ADMIN = array(
     9 => 'Link Description',
     10 => 'You need to provide a link Title, URL and Description.',
     11 => 'Link Manager',
-    12 => 'To modify or delete a link, click on that link\'s edit icon below.  To create a new link or a new category, click on "New link" or "New category" above. To edit multiple categories, click on "Edit categories" above.',
+    12 => 'To modify or delete a link, click on that link\'s edit icon below.  To create a new link or a new category, click on "New link" or "New category" above. To edit multiple categories, click on "List categories" above.',
     14 => 'Link Category',
     16 => 'Access Denied',
     17 => "You are trying to access a link that you don't have rights to.  This attempt has been logged. Please <a href=\"{$_CONF['site_admin_url']}/plugins/links/index.php\">go back to the link administration screen</a>.",
@@ -181,7 +182,7 @@ $LANG_LINKS_ADMIN = array(
     24 => 'Link not found',
     25 => 'The link you selected for editing could not be found.',
     26 => 'Validate Links',
-    27 => 'HTML Status',
+    27 => 'HTTP Status',
     28 => 'Edit category',
     29 => 'Enter or edit the details below.',
     30 => 'Category',
@@ -277,18 +278,28 @@ $LANG_confignames['links'] = array(
     'new_window' => 'Open external links in new window?',
     'root' => 'ID of Root Category',
     'default_permissions' => 'Link Default Permissions',
-    'category_permissions' => 'Category Default Permissions'
+    'category_permissions' => 'Category Default Permissions',
+    'autotag_permissions_link' => '[link: ] Permissions'    
 );
 
 $LANG_configsubgroups['links'] = array(
     'sg_main' => 'Main Settings'
 );
 
+$LANG_tab['links'] = array(
+    'tab_public' => 'Public Links List Settings',
+    'tab_admin' => 'Links Admin Settings',
+    'tab_permissions' => 'Link Permissions',
+    'tab_cpermissions' => 'Category Permissions', 
+    'tab_autotag_permissions' => 'Autotag Usage Permissions'
+);
+
 $LANG_fs['links'] = array(
     'fs_public' => 'Public Links List Settings',
     'fs_admin' => 'Links Admin Settings',
     'fs_permissions' => 'Link Permissions',
-    'fs_cpermissions' => 'Category Permissions'
+    'fs_cpermissions' => 'Category Permissions',
+    'fs_autotag_permissions' => 'Autotag Usage Permissions'  
 );
 
 // Note: entries 0, 1, and 12 are the same as in $LANG_configselects['Core']
@@ -296,7 +307,8 @@ $LANG_configselects['links'] = array(
     0 => array('True' => 1, 'False' => 0),
     1 => array('True' => TRUE, 'False' => FALSE),
     9 => array('Forward to Linked Site' => 'item', 'Display Admin List' => 'list', 'Display Public List' => 'plugin', 'Display Home' => 'home', 'Display Admin' => 'admin'),
-    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3)
+    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3),
+    13 => array('No access' => 0, 'Use' => 2)
 );
 
 ?>
