@@ -45,6 +45,7 @@ $LANG_STATIC = array(
     'writtenby' => '所有者',
     'date' => '最終更新日',
     'title' => 'タイトル',
+    'page_title' => 'ページタイトル',
     'content' => '内容',
     'hits' => '閲覧数',
     'staticpagelist' => '静的ページ管理',
@@ -107,19 +108,31 @@ $LANG_STATIC = array(
     'select_php_none' => 'PHPを実行しない',
     'select_php_return' => 'PHPを実行する (return)',
     'select_php_free' => 'PHPを実行する',
-    'php_not_activated' => "静的ページでPHPは使用しない設定になっています。詳細については <a href=\"{$_CONF['site_url']}/docs/japanese/staticpages.html#php\">関連ドキュメント</a> をご覧下さい。",
+    'php_not_activated' => "静的ページでPHPは使用しない設定になっています。詳細については <a href=\"{$_CONF['site_url']}/docs/japanese/staticpages.html#php\">関連ドキュメント</a> を参照してください。",
     'printable_format' => '印刷用フォーマット',
     'copy' => 'コピー',
     'limit_results' => '絞込検索',
     'search' => '検索',
     'submit' => '登録',
     'no_new_pages' => '-',
-    'pages' => 'ページ'
+    'pages' => 'ページ',
+    'comments' => 'コメント',
+    'template' => 'テンプレート',
+    'use_template' => '選択',
+    'template_msg' => 'チェックされた場合、静的ページはテンプレートとして利用されます。',
+    'none' => 'なし',
+    'use_template_msg' => 'この静的ページがテンプレートでなければ、テンプレートを選んで利用できます。利用する場合は、このページのコンテンツをXML形式で記述しなければならないので注意してください。',
+    'draft' => 'ドラフト',
+    'draft_yes' => '○',
+    'draft_no' => '-',
+    'autotag_desc_staticpage' => '[staticpage: id alternate title] - 静的ページタイトルで静的ページへのリンクを表示。アンカーテキストの指定は任意。',
+    'autotag_desc_staticpage_content' => '[staticpage_content: id alternate title] - 静的ページのコンテンツを表示。'
 );
 
 $PLG_staticpages_MESSAGE15 = 'コメントは投稿されました。管理者の承認をお待ちください。';
 $PLG_staticpages_MESSAGE19 = '静的ページを保存しました。';
 $PLG_staticpages_MESSAGE20 = '静的ページを削除しました。';
+$PLG_staticpages_MESSAGE21 = 'このページはありません。ページを作成するには、下のフォームにすべてを入力してください。ミスオペレーションならキャンセルボタンをクリックして戻ってください。';
 
 // Messages for the plugin upgrade
 $PLG_staticpages_MESSAGE3001 = 'プラグインのアップグレードはサポートされていません。';
@@ -135,6 +148,7 @@ $LANG_confignames['staticpages'] = array(
     'allow_php' => 'PHPを許可する',
     'sort_by' => 'センターブロックでのソート項目',
     'sort_menu_by' => 'メニューでのソート項目',
+    'sort_list_by' => '管理者ページソート順',
     'delete_pages' => '所有者の削除と共に削除する',
     'in_block' => 'ページをブロックで囲む',
     'show_hits' => '閲覧数を表示する',
@@ -142,11 +156,15 @@ $LANG_confignames['staticpages'] = array(
     'filter_html' => 'HTMLフィルターを適用する',
     'censor' => '内容を検閲する',
     'default_permissions' => 'パーミッション',
+    'autotag_permissions_staticpage' => '[staticpage: ] パーミッション',
+    'autotag_permissions_staticpage_content' => '[staticpage_content: ] パーミッション',
     'aftersave' => 'ページ保存後の画面遷移',
     'atom_max_items' => 'フィードに書き出す最大ページ数',
     'meta_tags' => 'メタタグを有効にする',
+    'comment_code' => '新規作成時のデフォルト',
+    'draft_flag' => 'ドラフトモードをデフォルトにする',
     'newstaticpagesinterval' => '静的ページの"新着"の期間',
-    'hidenewstaticpages' => '新着ページを表示しない',
+    'hidenewstaticpages' => '新着ブロック表示',
     'title_trim_length' => 'タイトル最大長',
     'includecenterblocks' => 'センターブロックの静的ページを含む',
     'includephp' => '静的ページPHPを含む',
@@ -159,21 +177,34 @@ $LANG_configsubgroups['staticpages'] = array(
     'sg_main' => 'メイン'
 );
 
+$LANG_tab['staticpages'] = array(
+    'tab_main' => '静的ページのメイン設定',
+    'tab_whatsnew' => '新着情報ブロック',
+    'tab_search' => '検索',
+    'tab_permissions' => 'パーミッションのデフォルト',
+    'tab_autotag_permissions' => '自動タグのパーミッション'
+);
+
 $LANG_fs['staticpages'] = array(
     'fs_main' => '静的ページのメイン設定',
     'fs_whatsnew' => '新着情報ブロック',
     'fs_search' => '検索結果',
-    'fs_permissions' => '静的ページのパーミッションのデフォルト（[0]所有者 [1]グループ [2]メンバー [3]ゲスト）'
+    'fs_permissions' => '静的ページのパーミッションのデフォルト（[0]所有者 [1]グループ [2]メンバー [3]ゲスト）',
+    'fs_autotag_permissions' => '自動タグのパーミッション'
 );
 
-// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
+// Note: entries 0, 1, 9, 12, 17 are the same as in $LANG_configselects['Core']
 $LANG_configselects['staticpages'] = array(
     0 => array('はい' => 1, 'いいえ' => 0),
-    1 => array('はい' => TRUE, 'いいえ' => FALSE),
+    1 => array('はい' => true, 'いいえ' => false),
     2 => array('日付' => 'date', 'ページID' => 'id', 'タイトル' => 'title'),
     3 => array('日付' => 'date', 'ページID' => 'id', 'タイトル' => 'title', 'ラベル' => 'label'),
-    9 => array('編集した静的ページを表示する' => 'item', '静的ページ管理を表示する' => 'list', 'ホームを表示する' => 'home', '管理画面トップを表示する' => 'admin'),
-    12 => array('アクセス不可' => 0, '表示' => 2, '表示・編集' => 3)
+    4 => array('日付' => 'date', 'ページID' => 'id', 'タイトル' => 'title', '所有者' => 'author'),
+    5 => array('表示しない' => 'hide', '編集日付によって表示する' => 'modified', '作成日付によって表示する' => 'created'),
+    9 => array('ページを表示する' => 'item', 'リストを表示する' => 'list', 'ホームを表示する' => 'home', '管理画面トップを表示する' => 'admin'),
+    12 => array('アクセス不可' => 0, '表示' => 2, '表示・編集' => 3),
+    13 => array('アクセス不可' => 0, '利用する' => 2),
+    17 => array('コメント有効' => 0, 'コメント無効' => -1)
 );
 
 ?>
