@@ -2,21 +2,21 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.6                                                               |
+// | Geeklog 1.7                                                               |
 // +---------------------------------------------------------------------------+
 // | chinese_simplified_utf-8.php                                              |
 // |                                                                           |
 // | Chinese language file for the Geeklog installation script                 |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2009 by the following authors:                         |
+// | Copyright (C) 2000-2010 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs         - tony AT tonybibbs DOT com                   |
 // |          Mark Limburg       - mlimburg AT users DOT sourceforge DOT net   |
 // |          Jason Whittenburg  - jwhitten AT securitygeeks DOT com           |
 // |          Dirk Haun          - dirk AT haun-online DOT de                  |
-// |          Randy Kolenko      - randy AT nextide DOT ca				       |
-// |          Matt West          - matt AT mattdanger DOT net			       |
-// |		  Samuel Maung Stone - sam AT stonemicro DOT com                   |
+// |          Randy Kolenko      - randy AT nextide DOT ca                     |
+// |          Matt West          - matt AT mattdanger DOT net                  |
+// |          Samuel Maung Stone - sam AT stonemicro DOT com                   |
 // +---------------------------------------------------------------------------+
 // |                                                                           |
 // | This program is free software; you can redistribute it and/or             |
@@ -155,7 +155,10 @@ $LANG_INSTALL = array(
     102 => 'Enter configuration information',
     103 => 'and configure additional plugins',
     104 => 'Incorrect Admin Directory Path',
-    105 => 'Sorry, but the admin directory path you entered does not appear to be correct. Please go back and try again.'
+    105 => 'Sorry, but the admin directory path you entered does not appear to be correct. Please go back and try again.',
+    106 => 'PostgreSQL',
+    107 => 'Database Password is required for production environments.',
+    108 => 'No Database Drivers found!'
 );
 
 // +---------------------------------------------------------------------------+
@@ -284,9 +287,7 @@ $LANG_BIGDUMP = array(
     8 => 'Processing file:',
     9 => 'Can\'t set file pointer behind the end of file.',
     10 => 'Can\'t set file pointer to offset: ',
-    11 => 'Stopped at the line ',
-    12 => '. At this place the current query is from csv file, but ',
-    13 => ' was not set.',
+    11 => 'There is no MySQL extension available in your PHP installation.',
     14 => 'Stopped at the line ',
     15 => '. At this place the current query includes more than ',
     16 => ' dump lines. That can happen if your dump file was created by some tool which doesn\'t place a semicolon followed by a linebreak at the end of each query, or if your dump contains extended inserts. Please read the BigDump FAQs for more information.',
