@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Polls Plugin 2.0                                                          |
+// | Polls Plugin 2.1                                                          |
 // +---------------------------------------------------------------------------+
 // | index.php                                                                 |
 // |                                                                           |
-// | Geeklog poll administration page                                          |
+// | Polls plugin administration page                                          |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2008 by the following authors:                         |
+// | Copyright (C) 2000-2011 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
 // |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
@@ -31,27 +31,31 @@
 // | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
 // |                                                                           |
 // +---------------------------------------------------------------------------+
-//
-// $Id: index.php,v 1.59 2008/06/10 17:26:50 dhaun Exp $
+
+/**
+* Polls plugin administration page
+*
+* @package Polls
+* @subpackage admin
+*/
+
+/**
+* Geeklog common function library and Admin authentication
+*/
+require_once '../../../lib-common.php';
+require_once '../../auth.inc.php';
 
 // Set this to true if you want to log debug messages to error.log
 $_POLL_VERBOSE = false;
 
-require_once '../../../lib-common.php';
-require_once '../../auth.inc.php';
-
-
 $display = '';
 
-if (!SEC_hasRights ('polls.edit')) {
-    $display .= COM_siteHeader ('menu', $MESSAGE[30]);
-    $display .= COM_startBlock ($MESSAGE[30], '',
-                                COM_getBlockTemplate ('_msg_block', 'header'));
-    $display .= $MESSAGE[36];
-    $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
-    $display .= COM_siteFooter ();
-    COM_accessLog ("User {$_USER['username']} tried to illegally access the poll administration screen.");
-    echo $display;
+if (!SEC_hasRights('polls.edit')) {
+    $display .= COM_siteHeader('menu', $MESSAGE[30])
+             . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
+             . COM_siteFooter();
+    COM_accessLog("User {$_USER['username']} tried to illegally access the poll administration screen.");
+    COM_output($display);
     exit;
 }
 
@@ -103,7 +107,7 @@ function listpolls()
 
     $query_arr = array(
         'table' => 'polltopics',
-        'sql' => "SELECT *,UNIX_TIMESTAMP(date) AS unixdate "
+        'sql' => "SELECT *,UNIX_TIMESTAMP(created) AS unixdate "
             . "FROM {$_TABLES['polltopics']} WHERE 1=1",
         'query_fields' => array('topic'),
         'default_filter' => COM_getPermSql ('AND')
@@ -124,9 +128,12 @@ function listpolls()
 * Saves a poll topic and potential answers to the database
 *
 * @param    string  $pid            Poll topic ID
+* @param    string  $old_pid        Previous poll topic ID
 * @param    array   $Q              Array of poll questions
 * @param    string  $mainpage       Checkbox: poll appears on homepage
 * @param    string  $topic          The text for the topic
+* @param    string  $meta_description
+* @param    string  $meta_keywords
 * @param    int     $statuscode     (unused)
 * @param    string  $open           Checkbox: poll open for voting
 * @param    string  $hideresults    Checkbox: hide results until closed
@@ -143,9 +150,9 @@ function listpolls()
 * @return   string                  HTML redirect or error message
 *
 */
-function savepoll($pid, $Q, $mainpage, $topic, $statuscode, $open, $hideresults,
-                  $commentcode, $A, $V, $R, $owner_id, $group_id, $perm_owner,
-                  $perm_group, $perm_members, $perm_anon)
+function savepoll($pid, $old_pid, $Q, $mainpage, $topic, $meta_description, $meta_keywords, $statuscode, $open,
+                  $hideresults, $commentcode, $A, $V, $R, $owner_id, $group_id,
+                  $perm_owner, $perm_group, $perm_members, $perm_anon)
 
 {
     global $_CONF, $_TABLES, $_USER, $LANG21, $LANG25, $MESSAGE, $_POLL_VERBOSE,
@@ -156,11 +163,21 @@ function savepoll($pid, $Q, $mainpage, $topic, $statuscode, $open, $hideresults,
     // Convert array values to numeric permission values
     list($perm_owner,$perm_group,$perm_members,$perm_anon) = SEC_getPermissionValues($perm_owner,$perm_group,$perm_members,$perm_anon);
 
-    $pid = COM_sanitizeID($pid);
     $topic = COM_stripslashes($topic);
+    $meta_description = strip_tags(COM_stripslashes($meta_description));
+    $meta_keywords = strip_tags(COM_stripslashes($meta_keywords));
+    $pid = COM_sanitizeID($pid);
+    $old_pid = COM_sanitizeID($old_pid);
+    if (empty($pid)) {
+        if (empty($old_pid)) {
+            $pid = COM_makeSid();
+        } else {
+            $pid = $old_pid;
+        }
+    }
 
     // check if any question was entered
-    if (empty($topic) or (sizeof($Q) == 0) or (strlen($Q[0]) == 0) or
+    if (empty($topic) or (count($Q) == 0) or (strlen($Q[0]) == 0) or
             (strlen($A[0][0]) == 0)) {
         $retval .= COM_siteHeader ('menu', $LANG25[5]);
         $retval .= COM_startBlock ($LANG21[32], '',
@@ -177,12 +194,21 @@ function savepoll($pid, $Q, $mainpage, $topic, $statuscode, $open, $hideresults,
                            . '/plugins/polls/index.php');
     }
 
+    // check for poll id change
+    if (!empty($old_pid) && ($pid != $old_pid)) {
+        // check if new pid is already in use
+        if (DB_count($_TABLES['polltopics'], 'pid', $pid) > 0) {
+            // TBD: abort, display editor with all content intact again
+            $pid = $old_pid; // for now ...
+        }
+    }
+
     // start processing the poll topic
     if ($_POLL_VERBOSE) {
         COM_errorLog ('**** Inside savepoll() in '
                       . $_CONF['site_admin_url'] . '/plugins/polls/index.php ***');
     }
-    $pid = str_replace (' ', '', $pid); // strip spaces from poll id
+
     $access = 0;
     if (DB_count ($_TABLES['polltopics'], 'pid', $pid) > 0) {
         $result = DB_query ("SELECT owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon FROM {$_TABLES['polltopics']} WHERE pid = '{$pid}'");
@@ -194,47 +220,56 @@ function savepoll($pid, $Q, $mainpage, $topic, $statuscode, $open, $hideresults,
         $access = SEC_hasAccess ($owner_id, $group_id, $perm_owner,
                                  $perm_group, $perm_members, $perm_anon);
     }
-    if (($access < 3) || !SEC_inGroup ($group_id)) {
-        $display .= COM_siteHeader ('menu', $MESSAGE[30]);
-        $display .= COM_startBlock ($MESSAGE[30], '',
-                            COM_getBlockTemplate ('_msg_block', 'header'));
-        $display .= $MESSAGE[31];
-        $display .= COM_endBlock ();
-        $display .= COM_siteFooter (COM_getBlockTemplate ('_msg_block',
-                                                          'footer'));
+    if (($access < 3) || !SEC_inGroup($group_id)) {
+        $display .= COM_siteHeader('menu', $MESSAGE[30])
+                 . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
+                 . COM_siteFooter();
         COM_accessLog("User {$_USER['username']} tried to illegally submit or edit poll $pid.");
-        echo $display;
+        COM_output($display);
         exit;
     }
 
-    if (empty ($voters)) {
-        $voters = 0;
-    }
-
     if ($_POLL_VERBOSE) {
         COM_errorLog('owner permissions: ' . $perm_owner, 1);
         COM_errorLog('group permissions: ' . $perm_group, 1);
         COM_errorLog('member permissions: ' . $perm_members, 1);
         COM_errorLog('anonymous permissions: ' . $perm_anon, 1);
     }
-    // we delete everything and re-create it with the input from the form
-    DB_delete ($_TABLES['polltopics'], 'pid', $pid);
-    DB_delete ($_TABLES['pollanswers'], 'pid', $pid);
-    DB_delete ($_TABLES['pollquestions'], 'pid', $pid);
 
-    $topic = addslashes ($topic);
+    // we delete everything and re-create it with the input from the form
+    $del_pid = $pid;
+    if (!empty($old_pid) && ($pid != $old_pid)) {
+        $del_pid = $old_pid; // delete by old pid, create using new pid below
+    }
+    // Retrieve Created Date before delete
+    $created_date = DB_getItem($_TABLES['polltopics'], 'created', "pid = '{$del_pid}'");
+    if ($created_date == '') {
+        $created_date = date ('Y-m-d H:i:s');
+    }
+    
+    DB_delete($_TABLES['polltopics'], 'pid', $del_pid);
+    DB_delete($_TABLES['pollanswers'], 'pid', $del_pid);
+    DB_delete($_TABLES['pollquestions'], 'pid', $del_pid);
+
+    $topic = addslashes($topic);
+    $meta_description = addslashes($meta_description);
+    $meta_keywords = addslashes($meta_keywords);
 
     $k = 0; // set up a counter to make sure we do assign a straight line of question id's
-    $v = 0; // re-count votes sine they might have been changed
     // first dimension of array are the questions
-    for ($i=0; $i<sizeof($Q); $i++) {
-        $Q[$i] = COM_stripslashes ($Q[$i]);
-        if (strlen ($Q[$i]) > 0) { // only insert questions that exist
-            DB_save ($_TABLES['pollquestions'], 'qid, pid, question', "'$k', '$pid', '$Q[$i]'");
-            // within the questions, we have another dimensions with answers, votes and remarks
-            for ($j=0; $j<sizeof($A[$i]); $j++) {
-                $A[$i][$j] = COM_stripslashes ($A[$i][$j]);
-                if (strlen ($A[$i][$j]) > 0) { // only insert answers etc that exist
+    $num_questions = count($Q);
+    for ($i = 0; $i < $num_questions; $i++) {
+        $Q[$i] = COM_stripslashes($Q[$i]);
+        if (strlen($Q[$i]) > 0) { // only insert questions that exist
+            $Q[$i] = addslashes($Q[$i]);
+            DB_save($_TABLES['pollquestions'], 'qid, pid, question',
+                                               "'$k', '$pid', '$Q[$i]'");
+            // within the questions, we have another dimensions with answers,
+            // votes and remarks
+            $num_answers = count($A[$i]);
+            for ($j = 0; $j < $num_answers; $j++) {
+                $A[$i][$j] = COM_stripslashes($A[$i][$j]);
+                if (strlen($A[$i][$j]) > 0) { // only insert answers etc that exist
                     if (!is_numeric($V[$i][$j])) {
                         $V[$i][$j] = "0";
                     }
@@ -243,14 +278,17 @@ function savepoll($pid, $Q, $mainpage, $topic, $statuscode, $open, $hideresults,
                     $sql = "INSERT INTO {$_TABLES['pollanswers']} (pid, qid, aid, answer, votes, remark) VALUES "
                         . "('$pid', '$k', " . ($j+1) . ", '{$A[$i][$j]}', {$V[$i][$j]}, '{$R[$i][$j]}');";
                     DB_query($sql);
-                    $v = $v + $V[$i][$j];
                 }
             }
             $k++;
         }
     }
+    
+    // determine the number of voters
+    $numvoters = DB_count($_TABLES['pollvoters'], 'pid', $pid);
+    
     // save topics after the questions so we can include question count into table
-    $sql = "'$pid','$topic',$v, $k, '" . date ('Y-m-d H:i:s');
+    $sql = "'$pid','$topic','$meta_description','$meta_keywords',$numvoters, $k, '$created_date', '" . date ('Y-m-d H:i:s');
 
     if ($mainpage == 'on') {
         $sql .= "',1";
@@ -271,9 +309,15 @@ function savepoll($pid, $Q, $mainpage, $topic, $statuscode, $open, $hideresults,
     $sql .= ",'$statuscode','$commentcode',$owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon";
 
     // Save poll topic
-    DB_save($_TABLES['polltopics'],"pid, topic, voters, questions, date, display, "
-           . "is_open, hideresults, statuscode, commentcode, owner_id, group_id, "
-           . "perm_owner, perm_group, perm_members, perm_anon",$sql);
+    DB_save($_TABLES['polltopics'], "pid, topic, meta_description, meta_keywords, voters, questions, created, modified, display, is_open, hideresults, statuscode, commentcode, owner_id, group_id, perm_owner, perm_group, perm_members, perm_anon", $sql);
+
+    if (empty($old_pid) || ($old_pid == $pid)) {
+        PLG_itemSaved($pid, 'polls');
+    } else {
+        DB_change($_TABLES['comments'], 'sid', addslashes($pid),
+                  array('sid', 'type'), array(addslashes($old_pid), 'polls'));
+        PLG_itemSaved($pid, 'polls', $old_pid);
+    }
 
     if ($_POLL_VERBOSE) {
         COM_errorLog ('**** Leaving savepoll() in '
@@ -302,38 +346,11 @@ function savepoll($pid, $Q, $mainpage, $topic, $statuscode, $open, $hideresults,
 function editpoll ($pid = '')
 {
     global $_CONF, $_PO_CONF, $_GROUPS, $_TABLES, $_USER, $LANG25, $LANG_ACCESS,
-           $LANG_ADMIN, $MESSAGE, $LANG_POLLS;
+           $LANG_ADMIN, $MESSAGE, $LANG_POLLS, $_SCRIPTS;
 
     $retval = '';
 
-    // writing the menu on top
-    require_once( $_CONF['path_system'] . 'lib-admin.php' );
-    $menu_arr = array (
-        array('url' => $_CONF['site_admin_url'] . '/plugins/polls/index.php',
-              'text' => $LANG_ADMIN['list_all']),
-        array('url' => $_CONF['site_admin_url'],
-              'text' => $LANG_ADMIN['admin_home']));
-
-    $retval .= COM_startBlock ($LANG25[5], '',
-                               COM_getBlockTemplate ('_admin_block', 'header'));
-
-    $retval .= ADMIN_createMenu(
-        $menu_arr,
-        $LANG_POLLS['editinstructions'],
-        plugin_geticon_polls()
-    );
-
-    $poll_templates = new Template ($_CONF['path']
-                                    . 'plugins/polls/templates/admin/');
-    $poll_templates->set_file (array ('editor' => 'polleditor.thtml',
-                                      'question' => 'pollquestions.thtml',
-                                      'answer' => 'pollansweroption.thtml'));
-    $poll_templates->set_var ( 'xhtml', XHTML );
-    $poll_templates->set_var ('site_url', $_CONF['site_url']);
-    $poll_templates->set_var ('site_admin_url', $_CONF['site_admin_url']);
-    $poll_templates->set_var ('layout_url', $_CONF['layout_url']);
-
-    if (!empty ($pid)) {
+    if (!empty($pid)) {
         $topic = DB_query("SELECT * FROM {$_TABLES['polltopics']} WHERE pid='$pid'");
         $T = DB_fetchArray($topic);
 
@@ -341,15 +358,42 @@ function editpoll ($pid = '')
         $access = SEC_hasAccess($T['owner_id'],$T['group_id'],$T['perm_owner'],$T['perm_group'],$T['perm_members'],$T['perm_anon']);
         if ($access == 0 OR $access == 2) {
             // User doesn't have access...bail
-            $retval .= COM_startBlock ($LANG25[21], '',
-                               COM_getBlockTemplate ('_msg_block', 'header'));
+            $retval .= COM_startBlock($LANG25[21], '',
+                            COM_getBlockTemplate('_msg_block', 'header'));
             $retval .= $LANG25[22];
-            $retval .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+            $retval .= COM_endBlock(COM_getBlockTemplate('_msg_block', 'footer'));
             COM_accessLog("User {$_USER['username']} tried to illegally submit or edit poll $pid.");
             return $retval;
         }
     }
 
+    // writing the menu on top
+    require_once $_CONF['path_system'] . 'lib-admin.php';
+
+    $menu_arr = array (
+        array('url' => $_CONF['site_admin_url'] . '/plugins/polls/index.php',
+              'text' => $LANG_ADMIN['list_all']),
+        array('url' => $_CONF['site_admin_url'],
+              'text' => $LANG_ADMIN['admin_home']));
+
+    $token = SEC_createToken();
+
+    $retval .= COM_startBlock($LANG25[5], '',
+                              COM_getBlockTemplate('_admin_block', 'header'));
+
+    $retval .= ADMIN_createMenu(
+        $menu_arr,
+        $LANG_POLLS['editinstructions'],
+        plugin_geticon_polls()
+    );
+    $retval .= SEC_getTokenExpiryNotice($token);
+
+    $poll_templates = COM_newTemplate($_CONF['path']
+                                    . 'plugins/polls/templates/admin/');
+    $poll_templates->set_file (array ('editor' => 'polleditor.thtml',
+                                      'question' => 'pollquestions.thtml',
+                                      'answer' => 'pollansweroption.thtml'));
+
     if (!empty ($pid) AND ($access == 3) AND !empty ($T['owner_id'])) {
         $delbutton = '<input type="submit" value="' . $LANG_ADMIN['delete']
                    . '" name="mode"%s' . XHTML . '>';
@@ -361,6 +405,8 @@ function editpoll ($pid = '')
     } else {
         $T['pid'] = COM_makeSid ();
         $T['topic'] = '';
+        $T['meta_description'] = '';
+        $T['meta_keywords'] = '';
         $T['voters'] = 0;
         $T['display'] = 1;
         $T['is_open'] = 1;
@@ -376,6 +422,14 @@ function editpoll ($pid = '')
         $T['commentcode'] = $_CONF['comment_code'];
         $access = 3;
     }
+    
+    $poll_templates->set_var('noscript', COM_getNoScript(false, ''));        
+    
+    // Add JavaScript
+    // Hide the Advanced Editor as Javascript is required. If JS is enabled then the JS below will un-hide it
+    $js = 'document.getElementById("advanced_editor").style.display="";';                 
+    $_SCRIPTS->setJavaScript($js, true);    
+    $_SCRIPTS->setJavaScriptFile('polls_editor', '/polls/polls_editor.js');
 
     $poll_templates->set_var('lang_pollid', $LANG25[6]);
     $poll_templates->set_var('poll_id', $T['pid']);
@@ -383,6 +437,21 @@ function editpoll ($pid = '')
     $poll_templates->set_var('lang_topic', $LANG25[9]);
     $poll_templates->set_var('poll_topic', htmlspecialchars ($T['topic']));
     $poll_templates->set_var('lang_mode', $LANG25[1]);
+    
+    $poll_templates->set_var('lang_metadescription',
+                             $LANG_ADMIN['meta_description']);
+    $poll_templates->set_var('lang_metakeywords', $LANG_ADMIN['meta_keywords']);
+    if (!empty($T['meta_description'])) {
+        $poll_templates->set_var('meta_description', $T['meta_description']);
+    }
+    if (!empty($T['meta_keywords'])) {
+        $poll_templates->set_var('meta_keywords', $T['meta_keywords']);        
+    }
+    if (($_CONF['meta_tags'] > 0) && ($_PO_CONF['meta_tags'] > 0)) {
+        $poll_templates->set_var('hide_meta', '');
+    } else {
+        $poll_templates->set_var('hide_meta', ' style="display:none;"');
+    }
 
     $poll_templates->set_var('status_options', COM_optionList ($_TABLES['statuscodes'], 'code,name', $T['statuscode']));
     $poll_templates->set_var('comment_options', COM_optionList($_TABLES['commentcodes'],'code,name',$T['commentcode']));
@@ -417,6 +486,7 @@ function editpoll ($pid = '')
                              SEC_getGroupDropdown ($T['group_id'], $access));
     $poll_templates->set_var('lang_permissions', $LANG_ACCESS['permissions']);
     $poll_templates->set_var('lang_permissionskey', $LANG_ACCESS['permissionskey']);
+    $poll_templates->set_var('lang_perm_key', $LANG_ACCESS['permissionskey']);
     $poll_templates->set_var('permissions_editor', SEC_getPermissionsHTML($T['perm_owner'],$T['perm_group'],$T['perm_members'],$T['perm_anon']));
     $poll_templates->set_var('lang_permissions_msg', $LANG_ACCESS['permmsg']);
     $poll_templates->set_var('lang_answersvotes', $LANG25[10]);
@@ -474,7 +544,7 @@ function editpoll ($pid = '')
     $navbar->set_selected($LANG25[31] . " 1");
     $poll_templates->set_var ('navbar', $navbar->generate());
     $poll_templates->set_var('gltoken_name', CSRF_TOKEN);
-    $poll_templates->set_var('gltoken', SEC_createToken());
+    $poll_templates->set_var('gltoken', $token);
 
     $poll_templates->parse('output','editor');
     $retval .= $poll_templates->finish($poll_templates->get_var('output'));
@@ -505,10 +575,13 @@ function deletePoll ($pid)
         return COM_refresh ($_CONF['site_admin_url'] . '/plugins/polls/index.php');
     }
 
-    DB_delete ($_TABLES['polltopics'], 'pid', $pid);
-    DB_delete ($_TABLES['pollanswers'], 'pid', $pid);
-    DB_delete ($_TABLES['pollquestions'], 'pid', $pid);
-    DB_query ("DELETE FROM {$_TABLES['comments']} WHERE sid = '$pid' AND type = 'polls'");
+    DB_delete($_TABLES['polltopics'], 'pid', $pid);
+    DB_delete($_TABLES['pollanswers'], 'pid', $pid);
+    DB_delete($_TABLES['pollquestions'], 'pid', $pid);
+    DB_delete($_TABLES['comments'], array('sid', 'type'),
+                                    array($pid,  'polls'));
+
+    PLG_itemDeleted($pid, 'polls');
 
     return COM_refresh ($_CONF['site_admin_url'] . '/plugins/polls/index.php?msg=20');
 }
@@ -531,8 +604,18 @@ if ($mode == 'edit') {
     $display .= editpoll ($pid);
     $display .= COM_siteFooter ();
 } elseif (($mode == $LANG_ADMIN['save']) && !empty($LANG_ADMIN['save'])) {
-    $pid = COM_applyFilter ($_POST['pid']);
-    if (!empty ($pid)) {
+    $pid = COM_applyFilter($_POST['pid']);
+    $old_pid = '';
+    if (isset($_POST['old_pid'])) {
+        $old_pid = COM_applyFilter($_POST['old_pid']);
+    }
+    if (empty($pid) && !empty($old_pid)) {
+        $pid = $old_pid;
+    }
+    if (empty($old_pid) && (! empty($pid))) {
+        $old_pid = $pid;
+    }
+    if (!empty($pid)) {
         $statuscode = 0;
         if (isset ($_POST['statuscode'])) {
             $statuscode = COM_applyFilter ($_POST['statuscode'], true);
@@ -549,8 +632,10 @@ if ($mode == 'edit') {
         if (isset ($_POST['hideresults'])) {
             $hideresults = COM_applyFilter ($_POST['hideresults']);
         }
-        $display .= savepoll ($pid, $_POST['question'], $mainpage, $_POST['topic'],
-                        $statuscode, $open, $hideresults,
+        $display .= savepoll ($pid, $old_pid, $_POST['question'], $mainpage,
+                        $_POST['topic'], $_POST['meta_description'],
+                        $_POST['meta_keywords'], $statuscode, $open,
+                        $hideresults,
                         COM_applyFilter ($_POST['commentcode'], true),
                         $_POST['answer'], $_POST['votes'], $_POST['remark'],
                         COM_applyFilter ($_POST['owner_id'], true),
@@ -593,6 +678,6 @@ if ($mode == 'edit') {
     $display .= COM_siteFooter ();
 }
 
-echo $display;
+COM_output($display);
 
 ?>
