@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Calendar Plugin 1.0                                                       |
+// | Calendar Plugin 1.1                                                       |
 // +---------------------------------------------------------------------------+
 // | index.php                                                                 |
 // |                                                                           |
 // | Geeklog calendar plugin                                                   |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2008 by the following authors:                         |
+// | Copyright (C) 2000-2010 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
 // |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
@@ -31,8 +31,6 @@
 // | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
 // |                                                                           |
 // +---------------------------------------------------------------------------+
-//
-// $Id: index.php,v 1.27 2008/07/06 20:15:10 dhaun Exp $
 
 require_once '../lib-common.php';
 
@@ -45,25 +43,12 @@ require_once $_CONF['path_system'] . 'classes/calendar.class.php';
 
 $display = '';
 
-if (empty ($_USER['username']) &&
+if (COM_isAnonUser() &&
     (($_CONF['loginrequired'] == 1) || ($_CA_CONF['calendarloginrequired'] == 1))) {
-    $display .= COM_siteHeader('');
-    $display .= COM_startBlock ($LANG_LOGIN[1], '',
-                                COM_getBlockTemplate ('_msg_block', 'header'));
-    $login = new Template($_CONF['path_layout'] . 'submit');
-    $login->set_file (array ('login'=>'submitloginrequired.thtml'));
-    $login->set_var ( 'xhtml', XHTML );
-    $login->set_var ('login_message', $LANG_LOGIN[2]);
-    $login->set_var ('site_url', $_CONF['site_url']);
-    $login->set_var ('site_admin_url', $_CONF['site_admin_url']);
-    $login->set_var ('layout_url', $_CONF['layout_url']);
-    $login->set_var ('lang_login', $LANG_LOGIN[3]);
-    $login->set_var ('lang_newuser', $LANG_LOGIN[4]);
-    $login->parse ('output', 'login');
-    $display .= $login->finish ($login->get_var('output'));
-    $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+    $display .= COM_siteHeader('menu', $LANG_CAL_1[41]);
+    $display .= SEC_loginRequiredForm();
     $display .= COM_siteFooter();
-    echo $display;
+    COM_output($display);
     exit;
 }
 
@@ -404,7 +389,7 @@ if ($mode == 'personal' AND $_CA_CONF['personalcalendars'] == 0) {
     // turned on.
     $display .= $LANG_CAL_2[37];
     $display .= COM_siteFooter();
-    echo $display;
+    COM_output($display);
     exit;
 }
 
@@ -497,15 +482,11 @@ $cal->setCalendarMatrix ($month, $year);
 
 switch ($view) {
 case 'day':
-    $cal_templates = new Template($_CONF['path'] . 'plugins/calendar/templates/dayview');
+    $cal_templates = COM_newTemplate($_CONF['path'] . 'plugins/calendar/templates/dayview');
     $cal_templates->set_file(array('column'=>'column.thtml',
                                    'event'=>'singleevent.thtml',
                                    'dayview'=>'dayview.thtml',
                                    'quickadd'=>'quickaddform.thtml'));
-    $cal_templates->set_var ( 'xhtml', XHTML );
-    $cal_templates->set_var ('site_url', $_CONF['site_url']);
-    $cal_templates->set_var ('site_admin_url', $_CONF['site_admin_url']);
-    $cal_templates->set_var ('layout_url', $_CONF['layout_url']);
     $cal_templates->set_var('mode', $mode);
     $cal_templates->set_var('lang_day', $LANG_CAL_2[39]);
     $cal_templates->set_var('lang_week', $LANG_CAL_2[40]);
@@ -535,7 +516,7 @@ case 'day':
         );
     } else {
         $cal_templates->set_var('calendar_title', '[' . $_CONF['site_name'] . ' ' . $LANG_CAL_2[29]);
-        if (!empty($_USER['uid']) AND $_CA_CONF['personalcalendars'] == 1) {
+        if (!COM_isAnonUser() AND $_CA_CONF['personalcalendars'] == 1) {
             $cal_templates->set_var('calendar_toggle', '|&nbsp;'
                 . COM_createLink($LANG_CAL_2[12], $_CONF['site_url']
                     . "/calendar/index.php?mode=personal&amp;view=day&amp;month=$month&amp;day=$day&amp;year=$year") . ']'
@@ -549,17 +530,17 @@ case 'day':
     if ($mode == 'personal') {
         $calsql = "SELECT eid,title,datestart,dateend,timestart,timeend,allday,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon FROM {$_TABLES['personal_events']} "
                 . "WHERE (uid = {$_USER['uid']}) "
-                . "AND ((allday=1 AND datestart = \"$year-$month-$day\") "
-                . "OR (datestart >= \"$year-$month-$day 00:00:00\" AND datestart <= \"$year-$month-$day 23:59:59\") "
-                . "OR (dateend >= \"$year-$month-$day 00:00:00\" AND dateend <= \"$year-$month-$day 23:59:59\") "
-                . "OR (\"$year-$month-$day\" BETWEEN datestart AND dateend)) "
+                . "AND ((allday=1 AND datestart = '$year-$month-$day') "
+                . "OR (datestart >= '$year-$month-$day 00:00:00' AND datestart <= '$year-$month-$day 23:59:59') "
+                . "OR (dateend >= '$year-$month-$day 00:00:00' AND dateend <= '$year-$month-$day 23:59:59') "
+                . "OR ('$year-$month-$day' BETWEEN datestart AND dateend)) "
                 . "ORDER BY datestart,timestart";
     } else {
         $calsql = "SELECT eid,title,datestart,dateend,timestart,timeend,allday,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon FROM {$_TABLES['events']} WHERE ((allday=1 "
-                . "AND datestart = \"$year-$month-$day\") "
-                . "OR (datestart >= \"$year-$month-$day 00:00:00\" AND datestart <= \"$year-$month-$day 23:59:59\") "
-                . "OR (dateend >= \"$year-$month-$day 00:00:00\" AND dateend <= \"$year-$month-$day 23:59:59\") "
-                . "OR (\"$year-$month-$day\" BETWEEN datestart AND dateend))" . COM_getPermSql ('AND')
+                . "AND datestart = '$year-$month-$day') "
+                . "OR (datestart >= '$year-$month-$day 00:00:00' AND datestart <= '$year-$month-$day 23:59:59') "
+                . "OR (dateend >= '$year-$month-$day 00:00:00' AND dateend <= '$year-$month-$day 23:59:59') "
+                . "OR ('$year-$month-$day' BETWEEN datestart AND dateend))" . COM_getPermSql ('AND')
                 . " ORDER BY datestart,timestart";
     }
     $result = DB_query($calsql);
@@ -594,7 +575,6 @@ case 'day':
         $numevents = $hourcols[$i];
         if ($numevents > 0) {
             // $colsleft = $maxcols;
-            $cal_templates->set_var ('layout_url', $_CONF['path'] . 'plugins/calendar/templates/');
             for ($j = 1; $j <= $numevents; $j++) {
                 $A = current ($thedata);
                 $cal_templates->set_var ('event_time',
@@ -634,14 +614,10 @@ case 'day':
     break;
 
 case 'week':
-    $cal_templates = new Template($_CONF['path'] . 'plugins/calendar/templates');
+    $cal_templates = COM_newTemplate($_CONF['path'] . 'plugins/calendar/templates');
     $cal_templates->set_file(array('week'=>'weekview/weekview.thtml',
                                    'events'=>'weekview/events.thtml',
                                    'quickadd'=>'dayview/quickaddform.thtml'));
-    $cal_templates->set_var ( 'xhtml', XHTML );
-    $cal_templates->set_var ('site_url', $_CONF['site_url']);
-    $cal_templates->set_var ('site_admin_url', $_CONF['site_admin_url']);
-    $cal_templates->set_var ('layout_url', $_CONF['layout_url']);
     $cal_templates->set_var('mode', $mode);
     $cal_templates->set_var('lang_week', $LANG_CAL_2[27]);
     if ($mode == 'personal') {
@@ -652,7 +628,7 @@ case 'week':
         );
     } else {
         $cal_templates->set_var('calendar_title', '[' . $_CONF['site_name'] . ' ' . $LANG_CAL_2[29]);
-        if (!empty($_USER['uid']) AND $_CA_CONF['personalcalendars'] == 1) {
+        if (!COM_isAnonUser() AND $_CA_CONF['personalcalendars'] == 1) {
             $cal_templates->set_var('calendar_toggle', '|&nbsp;'
                 . COM_createLink($LANG_CAL_2[12], $_CONF['site_url']
                     . "/calendar/index.php?mode=personal&amp;view=week&amp;month=$month&amp;day=$day&amp;year=$year") . ']'
@@ -682,14 +658,24 @@ case 'week':
         $time_day1 = mktime (0, 0, 0, $month, $day + 1, $year);
         $time_day7 = mktime (0, 0, 0, $month, $day + 7, $year);
         $start_mname = strftime ('%B', $time_day1);
-        $eday = strftime ('%e', $time_day7);
+        // Check for Windows to find and replace the %e 
+        if (strtoupper(substr(PHP_OS, 0, 3)) == 'WIN') {
+            $eday = strftime ('%#d', $time_day7);
+        } else {          
+            $eday = strftime ('%e', $time_day7);
+        }
         $end_mname = strftime ('%B', $time_day7);
         $end_ynum = strftime ('%Y', $time_day7);
         $date_range = $start_mname . ' ' . strftime ('%e', $time_day1);
     } else {
         $start_mname = strftime ('%B', mktime (0, 0, 0, $month, $day, $year));
         $time_day6 = mktime (0, 0, 0, $month, $day + 6, $year);
-        $eday = strftime ('%e', $time_day6);
+        // Check for Windows to find and replace the %e 
+        if (strtoupper(substr(PHP_OS, 0, 3)) == 'WIN') {
+            $eday = strftime ('%#d', $time_day6);
+        } else {        
+            $eday = strftime ('%e', $time_day6);
+        }
         $end_mname = strftime ('%B', $time_day6);
         $end_ynum = strftime ('%Y', $time_day6);
         $date_range = $start_mname . ' ' . $day;
@@ -801,12 +787,8 @@ case 'week':
     break;
 
 case 'addentry':
-    if (SEC_checkToken()) {
-        $display .= plugin_submit_calendar($mode);
-        $display .= COM_siteFooter();
-    } else {
-        $display = COM_refresh($_CONF['site_url'] . '/calendar/index.php');
-    }
+     $display .= plugin_submit_calendar($mode);
+     $display .= COM_siteFooter();
     break;
 
 case 'savepersonal':
@@ -820,7 +802,7 @@ case 'savepersonal':
 default: // month view
 // Load templates
 
-$cal_templates = new Template($_CONF['path'] . 'plugins/calendar/templates');
+$cal_templates = COM_newTemplate($_CONF['path'] . 'plugins/calendar/templates');
 $cal_templates->set_file (array (
         'calendar'    => 'calendar.thtml',
         'week'        => 'calendarweek.thtml',
@@ -831,10 +813,6 @@ $cal_templates->set_file (array (
         'addevent'    => 'addeventoption.thtml'
         ));
 
-$cal_templates->set_var ( 'xhtml', XHTML );
-$cal_templates->set_var ('site_url', $_CONF['site_url']);
-$cal_templates->set_var ('site_admin_url', $_CONF['site_admin_url']);
-$cal_templates->set_var ('layout_url', $_CONF['layout_url']);
 $cal_templates->set_var ('mode', $mode);
 if ($mode == 'personal') {
     $cal_templates->set_var ('start_block', COM_startBlock ($LANG_CAL_2[12]));
@@ -971,11 +949,11 @@ for ($i = 1; $i <= 6; $i++) {
             }
 
             $calsql = "SELECT eid,title,datestart,dateend,timestart,timeend,allday,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon FROM $calsql_tbl WHERE "
-                    . "((datestart >= \"$year-$month-$curday->daynumber 00:00:00\" "
-                    . "AND datestart <= \"$year-$month-$curday->daynumber 23:59:59\") "
-                    . "OR (dateend >= \"$year-$month-$curday->daynumber 00:00:00\" "
-                    . "AND dateend <= \"$year-$month-$curday->daynumber 23:59:59\") "
-                    . "OR (\"$year-$month-$curday->daynumber\" BETWEEN datestart AND dateend))"
+                    . "((datestart >= '$year-$month-$curday->daynumber 00:00:00' "
+                    . "AND datestart <= '$year-$month-$curday->daynumber 23:59:59') "
+                    . "OR (dateend >= '$year-$month-$curday->daynumber 00:00:00' "
+                    . "AND dateend <= '$year-$month-$curday->daynumber 23:59:59') "
+                    . "OR ('$year-$month-$curday->daynumber' BETWEEN datestart AND dateend))"
                     . $calsql_filt . " ORDER BY datestart,timestart";
 
             $query2 = DB_query($calsql);
@@ -1054,8 +1032,7 @@ if ($mode == 'personal') {
     $cal_templates->set_var('lang_mastercal', $LANG_CAL_2[25] . $LANG_CAL_2[11]);
     $cal_templates->parse('master_calendar_option','mastercal',true);
 } else {
-    if (isset ($_USER['uid']) && ($_USER['uid'] > 1) &&
-            ($_CA_CONF['personalcalendars'] == 1)) {
+    if (!COM_isAnonUser() && ($_CA_CONF['personalcalendars'] == 1)) {
         $cal_templates->set_var('lang_mycalendar', $LANG_CAL_2[12]);
         $cal_templates->parse('personal_calendar_option','personalcal',true);
     } else {
@@ -1086,6 +1063,6 @@ break;
 
 } // end switch
 
-echo $display;
+COM_output($display);
 
 ?>
